@@ -2,7 +2,6 @@ from autobahn.twisted.websocket import connectWS
 from twisted.internet import reactor
 
 from agent.logger import setup_logger
-from agent.rabbitmq.client import RabbitMqClient
 from agent.rabbitmq.setup import setup_rabbitmq
 from agent.websocket.client import AgentWebSocketFactory
 
@@ -11,9 +10,8 @@ logger = setup_logger()
 
 def main():
     logger.info("Launching Agent...")
-    connectWS(AgentWebSocketFactory.get_instance())
     setup_rabbitmq()
-    RabbitMqClient.get_instance().start_rabbitmq_client()
+    connectWS(AgentWebSocketFactory.get_instance())
     reactor.run()
 
 
