@@ -4,16 +4,15 @@ from collections import namedtuple
 from agent.commands import dispatcher
 from agent.communication import logger
 from agent.exceptions.agent_error import AgentError
+from agent.rabbitmq.publisher import publisher_queue
 
 command = namedtuple("command", ["type", "body"])
 
 
-def process_message(payload):
-    from agent.rabbitmq.client import RabbitMqClient
-
+def process_message(payload: bytes) -> None:
     data = convert_message_to_json(payload.decode("utf8"))
-    if "nodeServiceId" in data.keys():
-        RabbitMqClient.get_instance().publish_message(data)
+    if data.get("nodeServiceId"):
+        publisher_queue.put(data)
     else:
         process_json_message(data)
 
