@@ -2,10 +2,8 @@ PROVISION_SERVICE = 'PROVISION_SERVICE'
 DELETE_SERVICE = 'DELETE_SERVICE'
 NODE_METRICS = 'NODE_METRICS'
 SERVICES_STATUS = 'SERVICES_STATUS'
-SERVICE_DETAILS = 'SERVICE_DETAILS'
 DELETE_NODE = 'DELETE_NODE'
 RESTART_SERVICE = 'RESTART_SERVICE'
-NOTIFY_CONTROL_CENTER = 'NOTIFY_CONTROL_CENTER'
 
 SERVICE_UP = 'UP'
 SERVICE_DOWN = 'DOWN'
@@ -17,6 +15,3 @@ FILTER_SMART_CARD_COMMANDS = ['grep -E "\<(ID|Chip/SmartCard)"', 'grep "Chip/Sma
 UNINSTALL_SCRIPT_FILE = 'uninstall.sh'
 
 DOCKER_COMPOSE_FILE = 'docker-compose.yaml'
-
-EXCHANGE = "agent"
-EXCHANGE_TYPE = "topic"
