@@ -2,13 +2,11 @@ from twisted.internet.task import LoopingCall
 
 from agent.scheduler import logger
 from agent.scheduler.metrics_task import MetricsTask
-from agent.scheduler.rabbitmq_task import RabbitMQTask
 from agent.scheduler.status_task import StatusTask
 
 TASKS = [
     StatusTask(),
-    MetricsTask(),
-    RabbitMQTask()
+    MetricsTask()
 ]
 
 
